package de.kif.common.model

import de.kif.common.SearchElement
import kotlinx.serialization.Serializable

@Serializable
data class Schedule(
    override val id: Long?,
    val workGroup: WorkGroup,
    val room: Room,
    val day: Int,
    val time: Int,
    val lookRoom: Boolean,
    val lookTime: Boolean,
    override val createdAt: Long = 0,
    override val updateAt: Long = 0
) : Model {

    override fun createSearch() = SearchElement(
        mapOf(
            "workgroup" to workGroup.name,
            "room" to room.name,
            "track" to (workGroup.track?.name ?: ""),
            "language" to workGroup.language.localeName
        ), mapOf(), mapOf(
            "day" to day.toDouble()
        )
    )

    fun getAbsoluteStartTime(): Int = day * 60 * 24 + time
    fun getAbsoluteEndTime(): Int = getAbsoluteStartTime() + workGroup.length

    companion object {
        fun timeToString(time: Int): String {
            var day = time % (24 * 60)
            if (day < 0) day += 24 * 60

            val hour = day / 60
            val minute = day % 60

            return hour.toString().padStart(2, '0') + ":" + minute.toString().padStart(2, '0')
        }
    }
}
